var async    = require('async');
var canvass;
var compareScreenshot;

module.exports = {
    '@tags': ['cf_input'],
    before: function (client) {
        client
            .url(client.launchUrl)
            .waitForElementVisible('body', 1000);
    },

    after: function (client) {

        client.end();
    },
    /**
     *  Test: 5-001
     *  Expects:
     *      - Hark Designer will be loaded in the browser.
     *      - Nodes should be drawn in the sheet
     */
    "5-001": function (client) {
        async.series([
                //load HARK Designer
                function(callback){
                    canvass = client.page.canvass();
                    canvass.navigate();

                    //check if body is now visible
                    canvass.expect.element('body').to.be.present;

                    //should have Main sheet
                    canvass.expect.element('@mainSheet').to.be.visible;

                    callback();
                },
                //add nodeLocalizeMUSIC
                function (callback) {
                    canvass.addNodeByName('LocalizeMUSIC', function () {
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-002
     *  Expects:
     *      - Context menu will be displayed
     */
    "5-002": function (client) {
        async.series([
                //mouse over nodeLocalizeMUSIC
                function (callback) {
                    client.moveToElement('#node_LocalizeMUSIC_1', 0, 0, function () {
                        callback();
                    });
                },
                //right click
                function (callback) {
                    client.mouseButtonClick('right', function(){
                        callback();
                    });
                },
                //context menu should be displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu', 1000, function () {
                        canvass.expect.element('@mainContextMenu').to.be.visible;
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-003
     *  Expects:
     *      - "Add Input" dialog will be displayed.
     */
    "5-003": function (client) {
        async.series([
                //Add Input option should be displayed
                function (callback) {
                    canvass.waitForElementPresent('@addInputOption', 1000, function () {
                        callback();
                    });
                },
                //click Add Input option
                function (callback) {
                    canvass.click('@addInputOption', function() {
                        callback();
                    });
                },
                //Add Input Dialog should be displayed
                function (callback) {
                    canvass.waitForElementVisible('@addInputOutputDialog', 1000, function () {
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-004
     *  Expects:
     *      - Dialog should be close after the "Add" button is clicked.
     *      - Node element should be added an input in the left side of the element with a name of "INPUT_1".
     */
    "5-004": function (client) {
        async.series([
                //Add button should be displayed
                function (callback) {
                    canvass.waitForElementVisible('@addInputOutputButton', 1000, function () {
                        callback();
                    });
                },
                //clear Input name text
                function (callback) {
                    canvass.clearValue('@addInputOutputText', function () {
                        callback();
                    });
                },
                //Set Input name
                function (callback) {
                    canvass.setValue('@addInputOutputText', 'INPUT_1', function () {
                        callback();
                    });
                },
                //click Add button
                function (callback) {
                    canvass.click('@addInputOutputButton', function(){
                        callback();
                    });
                },
                //Add Input dialog should be closed
                function (callback) {
                    canvass.waitForElementNotVisible('@addInputOutputDialog', 1000, function () {
                        callback();
                    });
                },
                //INPUT_1 should be displayed
                function (callback){
                    canvass.expect.element('@nodeLocalizeMUSICInput1').to.be.present;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-005
     *  Expects:
     *      - Dialog should be close after the "Add" button is clicked.
     *      - Node element should be added an input in the left side of the element with a name of "INPUT_1".
     */
    "5-005": function (client) {
        async.series([
                //add INPUT_2 input to nodeLocalizeMUSIC1
                function (callback) {
                    canvass.addInput(client, 'INPUT_2', '#node_LocalizeMUSIC_1', function () {
                        callback();
                    });
                },
                //INPUT_1 should be displayed
                function (callback){
                    canvass.expect.element('@nodeLocalizeMUSICInput2').to.be.present;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-006
     *  Expects:
     *      - Context menu will be displayed. Items for the context menu:
     *          1. Set as Input
     *          2. Delete this Input
     *      - For the default input of the node, items for the context menu:
     *          1. Set as Input
     *              only.
     */
    "5-006": function (client) {
        async.series([
                //mouse over INPUT_2
                function (callback) {
                    client
                        .moveToElement('#node_LocalizeMUSIC_1_delim_INPUT_2', 3, 3, function () {
                            callback();
                        });
                },
                //right click
                function (callback) {
                    client.mouseButtonClick('right', function(){
                        callback();
                    })
                },
                //context menu should be displayed
                function (callback) {
                    canvass.waitForElementPresent('@mainContextMenu2', 1000, function(){
                        canvass.expect.element('@mainContextMenu2').to.be.present;
                        callback();
                    });
                },
                //Delete this Input and Set as Input options should be displayed
                function (callback) {
                    canvass.expect.element('@deleteIOOption').to.be.present;
                    canvass.expect.element('@setAsIOOption').to.be.present;
                    callback();
                },
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-007
     *  Expects:
     *      - INPUT_2 should be deleted.
     */
    "5-007": function (client) {
        async.series([
                //click Delete Input option
                function (callback) {
                    canvass.click('@deleteIOOption', function() {
                        callback();
                    });
                },
                //INPUT_2 should be deleted
                function (callback) {
                    canvass.expect.element('@nodeLocalizeMUSICInput2').to.not.be.present;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-008
     *  Expects:
     *      - Context menu will be displayed.
     *      - Dialog will appper with default value depends on the name of the input. In this case, "INPUT" is the set value.
     *      - Red labeled "INPUT" should be drawn on the left side of the node.
     */
    "5-008": function (client) {
        async.series([
                //set INPUT of nodeLocalizeMusic1 as INPUT
                function (callback) {
                    canvass.setAsIO(client, '#node_LocalizeMUSIC_1_delim_INPUT', 'INPUT', function () {
                        callback();
                    });
                },
                //INPUT should have role as INPUT
                function (callback) {
                    canvass.expect.element('@inputRole').text.to.equal('INPUT');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-009
     *  Expects:
     *      - Context menu will be displayed.
     *      - Dialog will appper with default value depends on the name of the input. In this case, "INPUT_1" is the set value.
     *      - Red labeled "INPUT_1" should be drawn on the left side of the node.
     */
    "5-009": function (client) {
        async.series([
                //set INPUT_1 of nodeLocalizeMusic1 as INPUT_1
                function (callback) {
                    canvass.setAsIO(client, '#node_LocalizeMUSIC_1_delim_INPUT_1', 'INPUT_1', function () {
                        callback();
                    });
                },
                //INPUT_1 should have role as INPUT_1
                function (callback) {
                    canvass.expect.element('@input1Role').text.to.equal('INPUT_1');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-010
     *  Expects:
     *      - Context menu will be displayed.
     *      - Dialog will appper with default value depends on the name of the input. In this case, NOISECM is the set value.
     *      - Red labeled "NOISECM" should be drawn on the left side of the node.
     */
    "5-010": function (client) {
        async.series([
                //set NOISECM of nodeLocalizeMusic1 as NOISECM
                function (callback) {
                    canvass.setAsIO(client, '#node_LocalizeMUSIC_1_delim_NOISECM', 'NOISECM', function () {
                        callback();
                    });
                },
                //NOISECM should have role as NOISECM
                function (callback) {
                    canvass.expect.element('@noisecmRole').text.to.equal('NOISECM');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-011
     *  Expects:
     *      - Save file dialog will be closed
     */
    "5-011": function (client) {
        async.series([
                //save network
                function (callback) {
                    canvass.saveNetwork(client, 'sample_input.n', function(){
                        callback();
                    });
                },
                //save sheet dialog should be closed
                function (callback){
                    canvass.expect.element('@saveSheetDialog').to.not.be.visible;
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-012
     *  Expects:
     *      - The saved network "sample_input.n" will be loaded in the Hark Designer.
     *      - LocalizedMUSIC with red labeled inputs should be drawn in the sheet.
     */
    "5-012": function (client) {
        async.series([
                //load sample_input.n
                function (callback) {
                    canvass.loadNetwork(client, 'sample_input.n', function () {
                        canvass.expect.element('@fileDialog').to.not.be.visible;
                        callback();
                    })
                },
                //Inputs and roles should be displayed
                function (callback) {
                    canvass.expect.element('@nodeLocalizeMUSICInput1').to.be.present;
                    canvass.expect.element('@inputRole').to.be.present;
                    canvass.expect.element('@input1Role').to.be.present;
                    canvass.expect.element('@noisecmRole').to.be.present;
                    canvass.expect.element('@inputRole').text.to.equal('INPUT');
                    canvass.expect.element('@input1Role').text.to.equal('INPUT_1');
                    canvass.expect.element('@noisecmRole').text.to.equal('NOISECM');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-013
     *  Expects:
     *      - Red labeled input name will be removed.
     */
    "5-013": function (client) {
        async.series([
                //delete INPUT_1 role
                function (callback) {
                    canvass.deleteIO(client, '@deleteIOOption2', '#node_LocalizeMUSIC_1_delim_INPUT_1', function () {
                        callback();
                    });
                },
                //INPUT_1 role should be deleted
                function (callback) {
                    canvass.expect.element('@input1Role').text.to.not.equal('INPUT_1');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-014
     *  Expects:
     *      - Red labeled input name will be removed.
     */
    "5-014": function (client) {
        async.series([
                //delete NOISECM role
                function (callback) {
                    canvass.deleteIO(client, '@deleteIOOption2', '#node_LocalizeMUSIC_1_delim_NOISECM', function () {
                        callback();
                    });
                },
                //NOISECM role should be deleted
                function (callback) {
                    canvass.expect.element('@noisecmRole').text.to.not.equal('NOISECM');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-015
     *  Expects:
     *      - INPUT_1 will be removed.
     */
    "5-015": function (client) {
        async.series([
                //delete INPUT_1 role
                function (callback) {
                    canvass.deleteIO(client, '@deleteIOOption', '#node_LocalizeMUSIC_1_delim_INPUT_1', function () {
                        callback();
                    });
                },
                //INPUT_1 role should be deleted
                function (callback) {
                    canvass.expect.element('@nodeLocalizeMUSICInput1').to.not.be.present;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-016
     *  Expects:
     *      - Save file dialog will be closed
     */
    "5-016": function (client) {
        async.series([
                //save network
                function (callback) {
                    canvass.saveNetwork(client, 'sample_input.n', function(){
                        callback();
                    });
                },
                //save file dialog should be closed
                function (callback){
                    canvass.expect.element('@saveSheetDialog').to.not.be.visible;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-017
     *  Expects:
     *      - The saved network "sample_input.n" will be loaded in the Hark Designer.
     *      - LocalizedMUSIC with red labeled inputs should be drawn in the sheet.
     */
    "5-017": function (client) {
        async.series([
                //load sample_input.n
                function (callback) {
                    canvass.loadNetwork(client, 'sample_input.n', function () {
                        canvass.expect.element('@fileDialog').to.not.be.visible;
                        callback();
                    })
                },
                //Inputs and roles should be displayed
                function (callback) {
                    canvass.expect.element('@input1Role').to.not.be.present;
                    canvass.expect.element('@nodeLocalizeMUSICInput1').to.not.be.present;
                    canvass.expect.element('@inputRole').to.be.present;
                    canvass.expect.element('@inputRole').text.to.equal('INPUT');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-018
     *  Expects:
     *      - Dialog box will appear.
     *      -it should have 1 input box for Name
     *      -It should have Add and Cancel button
     */
    "5-018": function (client) {
        async.series([
                //click + button
                function (callback) {
                    canvass.click('@addSheetButton', function(){
                        callback();
                    });
                },
                //should have input box for name
                function (callback) {
                    canvass.expect.element('@sheetName').to.be.present;
                    callback();
                },
                //should have Add and Cancel button
                function (callback) {
                    canvass.expect.element('@addSheetSubmitButton').to.be.present;
                    canvass.expect.element('@addSheetCancelButton').to.be.present;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-019
     *  Expects:
     *      - Dialog box will be closed
     *      - New sheet with "Dynamic1" as title will be added and set as active- Dialog box will appear.
     */
    "5-019": function (client) {
        async.series([
                //set sheet name
                function (callback) {
                    canvass.setValue('@sheetName', 'Dynamic1', function(){
                        callback();
                    });
                },
                //click Add button
                function (callback) {
                    canvass.click('@addSheetSubmitButton', function(){
                        callback();
                    });
                },
                //dialog box should be closed
                function (callback) {
                    canvass.waitForElementNotVisible('@addSheetDialog', 1000, function(){
                        canvass.expect.element('@addSheetDialog').to.not.be.visible;
                        callback();

                    });
                },
                //Dynamic1 sheet should be created
                function (callback) {
                    canvass.expect.element('@dynamic1Sheet').to.be.visible;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-020
     *  Expects:
     *      - LocalizeMusic Node should be present in the sheet.
     */
    "5-020": function (client) {
        async.series([
                //Dynamic1 sheet should be visible
                function (callback) {
                    canvass.selectSheet('@dynamic1SheetTab', function () {
                        canvass.expect.element('@dynamic1Sheet').to.be.visible;
                        callback();
                    });
                },
                //add LocalizeMUSIC node
                function (callback) {
                    canvass.addNodeByName('LocalizeMUSIC', function () {
                        callback();
                    });
                },
                //LocalizeMUSIC node should be added
                function (callback) {
                    canvass.expect.element('@nodeLocalizeMUSIC2').to.be.visible;
                    callback();

                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-021
     *  Expects:
     *      - Context menu will be displayed.
     *      - Dialog will appper with default value depends on the name of the input. In this case, "INPUT" is the set value.
     *      - Red labeled "INPUT" should be drawn on the left side of the node.
     */
    "5-021": function (client) {
        async.series([
                //set INPUT of nodeLocalizeMusic2 as INPUT
                function (callback) {
                    canvass.setAsIO(client, '#node_LocalizeMUSIC_2_delim_INPUT', 'INPUT', function () {
                        callback();
                    });
                },
                //nodeLocalizeMUSIC2 shoudl have INPUT
                function (callback) {
                    canvass.expect.element('@inputRole2').text.to.equal('INPUT');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-022
     *  Expects:
     *      - Dialog box will appear.
     *      -it should have 1 input box for Name
     *      -It should have Add and Cancel button
     */
    "5-022": function (client) {
        async.series([
                //click + button
                function (callback) {
                    canvass.click('@addSheetButton', function(){
                        callback();
                    });
                },
                //should have input box for name
                function (callback) {
                    canvass.expect.element('@sheetName').to.be.present;
                    callback();
                },
                //should have Add and Cancel button
                function (callback) {
                    canvass.expect.element('@addSheetSubmitButton').to.be.present;
                    canvass.expect.element('@addSheetCancelButton').to.be.present;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-023
     *  Expects:
     *      - Dialog box will be closed
     *      - New sheet with "Dynamic2" as title will be added and set as active- Dialog box will appear.
     */
    "5-023": function (client) {
        async.series([
                //set sheet name
                function (callback) {
                    canvass.setValue('@sheetName', 'Dynamic2', function(){
                        callback();
                    });
                },
                //click Add button
                function (callback) {
                    canvass.click('@addSheetSubmitButton', function(){
                        callback();
                    });
                },
                //dialog box should be closed
                function (callback) {
                    canvass.waitForElementNotVisible('@addSheetDialog', 1000, function(){
                        canvass.expect.element('@addSheetDialog').to.not.be.visible;
                        callback();

                    });
                },
                //Dynamic1 sheet should be created
                function (callback) {
                    canvass.expect.element('@dynamic2Sheet').to.be.visible;
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-024
     *  Expects:
     *      - LocalizeMusic Node should be present in the sheet.
     */
    "5-024": function (client) {
        async.series([
                //Dynamic1 sheet should be visible
                function (callback) {
                    canvass.selectSheet('@dynamic2SheetTab', function () {
                        canvass.expect.element('@dynamic2Sheet').to.be.visible;
                        callback();
                    });
                },
                //add LocalizeMUSIC node
                function (callback) {
                    canvass.addNodeByName('LocalizeMUSIC', function () {
                        callback();
                    });
                },
                //LocalizeMUSIC node should be added
                function (callback) {
                    canvass.expect.element('@nodeLocalizeMUSIC3').to.be.visible;
                    callback();

                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-025
     *  Expects:
     *      - Context menu will be displayed.
     *      - Dialog will appper with default value depends on the name of the input. In this case, "INPUT" is the set value.
     *      - Red labeled "INPUT" should be drawn on the left side of the node.
     */
    "5-025": function (client) {
        async.series([
                //set INPUT of nodeLocalizeMusic3 as INPUT
                function (callback) {
                    canvass.setAsIO(client, '#node_LocalizeMUSIC_3_delim_INPUT', 'INPUT', function () {
                        callback();
                    });
                },
                //nodeLocalizeMUSIC3 shoudl have INPUT
                function (callback) {
                    canvass.expect.element('@inputRole3').text.to.equal('INPUT');
                    callback();
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-026
     *  Expects:
     *      - Dynamic1 sheet should be displayed with one LocalizeMUSIC node and one Dynamic2 node.
     *      - Dynamic2 node should have an INPUT.
     */
    "5-026": function (client) {
        async.series([
                //select Dynamic1 sheet
                function (callback) {
                    canvass.selectSheet('@dynamic1SheetTab', function () {
                        //Dynamic1 sheet should be visible
                        canvass.expect.element('@dynamic1Sheet').to.be.visible;
                        callback();
                    });
                },
                //add Dynamic2 dynamic node
                function (callback) {
                    canvass.addNodeByName('Dynamic2', function () {
                        //Dynamic1 node should be added
                        canvass.expect.element('@dynamic2Node').to.be.visible;
                        //Dynamic1 node should have INPUT
                        canvass.expect.element('@dynamic2NodeInput').to.be.present;

                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-027
     *  Expects:
     *      - OUTPUT of LocalizeMUSIC node should be connected to INPUT of Dynamic2 node.
     */
    "5-027": function (client) {
        async.series([
                //reposition nodeDynamic2
                function (callback) {
                    canvass.repositionNode(client, '#node_Dynamic2_1', 500, 200, function () {
                        callback();
                    });
                },
                //link nodeLocalizeMUSIC2 OUTPUT to nodeDynamic2 INPUT
                function (callback) {
                    canvass.linkNodes(client, '#node_LocalizeMUSIC_2_delim_OUTPUT > div', '#node_Dynamic2_1_delim_INPUT > div', 50, 0, function () {
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-028
     *  Expects:
     *      - MAIN sheet should be displayed with one LocalizeMUSIC node and one Dynamic1 node.
     *      - Dynamic1 node should have an INPUT.
     */
    "5-028": function (client) {
        async.series([
                //select MAIN sheet
                function (callback) {
                    canvass.selectSheet('@mainSheetTab', function () {
                        //MAIN sheet should be visible
                        canvass.expect.element('@mainSheet').to.be.visible;
                        callback();
                    });
                },
                //add Dynamic1 dynamic node
                function (callback) {
                    canvass.addNodeByName('Dynamic1', function () {
                        //Dynamic1 node should be added
                        canvass.expect.element('@dynamic1Node').to.be.visible;
                        //Dynamic1 node should have INPUT
                        canvass.expect.element('@dynamic1NodeInput').to.be.present;

                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-029
     *  Expects:
     *      - OUTPUT of LocalizeMUSIC node should be connected to INPUT of Dynamic1 node.
     */
    "5-029": function (client) {
        async.series([
                //reposition nodeDynamic1
                function (callback) {
                    canvass.repositionNode(client, '#node_Dynamic1_1', 500, 200, function () {
                        callback();
                    });
                },
                //link nodeLocalizeMUSIC1 OUTPUT to nodeDynamic1 INPUT
                function (callback) {
                    canvass.linkNodes(client, '#node_LocalizeMUSIC_1_delim_OUTPUT > div', '#node_Dynamic1_1_delim_INPUT > div', 50, 0, function () {
                        callback();
                    });
                },
                //hover mouse somewhere else
                function (callback) {
                    canvass.selectSheet('@mainSheetTab', function () {
                        canvass.api.pause(2000, function () {
                            callback();
                        });
                    });
                },
                //create screenshot
                function (callback) {
                    compareScreenshot = client.page.compareScreenshot();
                    compareScreenshot.screenshot('cf_input-5-029.png', client, function () {
                        callback();
                    });
                },
                //compare actual screenshot with expected
                function (callback) {
                    compareScreenshot.compare('cf_input-5-029.png', 'cf_input-5-029.png', function (result) {
                        client.assert.equal(result, true);
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-030
     *  Expects:
     *      - INPUT will be removed
     */
    "5-030": function (client) {
        async.series([
                //go to Dynamic2 sheet
                function (callback) {
                    canvass.selectSheet('@dynamic2SheetTab', function () {
                        //Dynamic1 sheet should be visible
                        canvass.expect.element('@dynamic2Sheet').to.be.visible;
                        callback();
                    });
                },
                //delete nodeDynamic2 INPUT
                function (callback) {
                    canvass.deleteIO(client, '@dynamic2SheetDeleteIOOption', '#node_LocalizeMUSIC_3_delim_INPUT', function () {
                        //role must be removed
                        canvass.expect.element('@inputRole3').text.to.not.equal('INPUT');
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-031
     *  Expects:
     *      - OUTPUT of LocalizeMUSIC node will be disconnected.
     *      - Dynamic2 should not have any input.
     */
    "5-031": function (client) {
        async.series([
                function (callback) {
                    //go to Dynamic1 sheet
                    canvass.selectSheet('@dynamic1SheetTab', function () {
                        //MAIN sheet should be visible
                        canvass.expect.element('@dynamic1Sheet').to.be.visible;
                        //nodeDynamic1 should have not INPUT
                        canvass.expect.element('@dynamic2NodeInput').to.not.be.present;

                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-032
     *  Expects:
     *      - INPUT will be removed
     */
    "5-032": function (client) {
        async.series([
                function (callback) {
                    //delete nodeDynamic1 INPUT
                    canvass.deleteIO(client, '@dynamic1SheetDeleteIOOption', '#node_LocalizeMUSIC_2_delim_INPUT', function () {
                        //role must be removed
                        canvass.expect.element('@inputRole2').text.to.not.equal('INPUT');
                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    },
    /**
     *  Test: 5-033
     *  Expects:
     *      - OUTPUT of LocalizeMUSIC node will be disconnected.
     *      - Dynamic1 should not have any input.
     */
    "5-033": function (client) {
        async.series([
                function (callback) {
                    //go to MAIN sheet
                    canvass.selectSheet('@mainSheetTab', function () {
                        //MAIN sheet should be visible
                        canvass.expect.element('@mainSheet').to.be.visible;
                        //nodeDynamic1 should have not INPUT
                        canvass.expect.element('@dynamic1NodeInput').to.not.be.present;

                        callback();
                    });
                }
            ],
            function(){
                //finished
            });
    }
};