var async = require('async');
var path = require('path');

var fixtureDir = '/usr/src/app/automated-tests/lib/fixtures';
var compareScreenshot;

module.exports = {
    //Display dialog test
    '@tags': ['pd_display'],

    before: function (client) {
        client
            .url('http://localhost:3000')
            .waitForElementVisible('#topmenu', 1000);
    },

    after: function (client) {
        client.end();
    },

    /**
     * Test: 2-001
     * Expects:
     *  - Preferences dialog will appear with 6 buttons
     */
    '2-001': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.expect.element('body').to.be.present;
                callback();
            },
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.expect.element('@preferenceDialog').to.be.visible;
                callback();
            },
            function (callback) {
                // 2-001
                preferenceTest.expect.element('@packagesBtn').to.be.visible;
                preferenceTest.expect.element('@displayBtn').to.be.visible;
                preferenceTest.expect.element('@versionBtn').to.be.visible;
                preferenceTest.expect.element('@resetBtn').to.be.visible;
                preferenceTest.expect.element('@tutorialBtn').to.be.visible;
                preferenceTest.expect.element('@environmentBtn').to.be.visible;
                callback();
            }
        ], function (err, stdout) {
        });
    },
    /**
     * Test: 2-002
     * Expects:
     *  -  Option for Line, Language, Show Tooltips and for Resetting of options are displayed.
     */
    '2-002': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.clickDisplayButton(function () {
                    callback();
                });
            },
            function (callback) {
                // 2-002
                preferenceTest.expect.element('@dialogMain').to.have.attribute('style').contains('display: block;');
                preferenceTest.expect.element('@displayDialogLine1').text.to.equal('Line:');
                preferenceTest.expect.element('@displayDialogLine2').text.to.equal('Language:');
                preferenceTest.expect.element('@displayDialogLine3').text.to.equal('Show Tooltips:');
                preferenceTest.expect.element('@displayDialogLine4').text.to.equal('Show Link Candidates:');
                preferenceTest.expect.element('@displayDialogLine5').text.to.equal('Re-align mode:');

                preferenceTest.expect.element('@displayDialogValue1').to.have.value.that.equals('Bezier');
                preferenceTest.expect.element('@displayDialogValue2').to.have.value.that.equals('en');
                preferenceTest.expect.element('@displayDialogValue3').to.have.value.that.equals('Yes');
                preferenceTest.expect.element('@displayDialogValue4').to.have.value.that.equals('Yes');
                preferenceTest.expect.element('@displayDialogValue5').to.have.value.that.equals('fold');
                callback();
            }
        ], function (err, stdout) {
        });
    },

    /**
     * Test: 2-003
     * Expects:
     *  - Nodes and links will be drawn in the canvass.
     *  - The default line type for Hark Designer will be in Bezier (curve lines).
     */
    '2-003': function (client) {
        var preferenceTest = client.page.preferenceManagement();
        compareScreenshot = client.page.compareScreenshot();
        async.series([
            function (callback) {
                preferenceTest.closeDialog(function () {
                    callback();
                })
            },
            function (callback) {
                preferenceTest.clickFileManagerButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.setValue('@uploadBtn', path.resolve(fixtureDir + '/sample.n'));
                callback();
            },
            function (callback) {
                client.getAlertText(function(alertText){
                    client.pause(1000);
                    if(alertText.value == 'Overwrite sample.n with sample.n?') {
                        //accept alert
                        client.acceptAlert(function () {
                            client.pause(1000, function () {
                                callback()
                            });
                        });
                    }
                    else {
                            callback();
                    }
                });
            },
            function (callback) {
                preferenceTest.click('@loadNetworkBtn');
                callback();
            },
            function (callback) {
                client.pause(1000, function () {
                    client.acceptAlert(function () {
                        callback();
                    });
                })
            },
            function (callback) {
                client.pause(3000, function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.selectSheet('@loopSheetTab', function () {
                    preferenceTest.api.pause(2000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                compareScreenshot.screenshot('pd_display-2-003.png', client, function () {
                    callback();
                });
            },
            function (callback) {
                compareScreenshot.compare('pd_display-2-003.png', 'pd_display-2-003.png', function (result) {
                    client.assert.equal(result, true);
                    callback();
                });
            }
        ], function (err, stdout) {
        });
    },

    /**
     * Test: 2-004
     * Expects:
     *  - There will be no curve lines drawn in the canvass.
     *  - Links should be drawn in straight and orthogonal lines.
     */
    '2-004': function (client) {
        var preferenceTest = client.page.preferenceManagement();
        compareScreenshot = client.page.compareScreenshot();
        async.series([
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                })
            },
            function (callback) {
                preferenceTest.clickDisplayButton(function () {
                    callback();
                })
            },
            function (callback) {
                preferenceTest.setValue('@displayDialogValue1', 'Lines');
                callback();
            },
            function (callback) {
                preferenceTest.closeDialog(function () {
                    callback();
                })
            },
            function (callback) {
                client.pause(3000, function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.selectSheet('@loopSheetTab', function () {
                    preferenceTest.api.pause(2000, function () {
                        callback();
                    });
                });
            },
            function (callback) {
                compareScreenshot.screenshot('pd_display-2-004.png', client, function () {
                    callback();
                });
            },
            function (callback) {
                compareScreenshot.compare('pd_display-2-004.png', 'pd_display-2-004.png', function (result) {
                    client.assert.equal(result, true);
                    callback();
                });
            },
        ], function (err, stdout) {
        });
    },

    /**
     * Test: 2-005
     * Expects:
     *  - Preference Dialog will close.
     *  - Instructions for the tutorial should be in Japanese.
     */
    '2-005': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.clickDisplayButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.setDisplayLanguageButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.clickTutorialButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.expect.element('@tutorialLabelStep').to.have.value.that.not.equals('You can build your network here.');
                callback();
            },

            function (callback) {
                preferenceTest.clickTutorialSkipBtn(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.expect.element('@tutorialLayer').to.not.be.present;
                callback();
            }
        ], function (err, stdout) {
        });
    },

    /**
     * Test: 2-006
     * Expects:
     *  - Tooltip will be displayed.
     */
    '2-006': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                client.refresh()
                    .pause(2000)
                    .acceptAlert();
                callback();
            },
            function (callback) {
                client.pause(3000);
                callback();
            },
            function (callback) {
                preferenceTest.moveToElement('@preferenceManagerBtn', 10, 10, function() {
                    client.pause(2000, function () {
                        preferenceTest.expect.element('@preferenceManagerBtn').to.have.attribute('aria-describedby', 'ui-tooltip');
                        callback();
                    })
                });
            }

        ], function (err, stdout) {
        });
    },

    /**
     * Test: 2-007
     * Expects:
     *  - There will be no tooltips be displayed everytime hovering an element.
     */
    '2-007': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.openDialog(function () {
                    callback();
                })
            },
            function (callback) {
                preferenceTest.clickDisplayButton(function () {
                    callback();
                })
            },
            function (callback) {
                preferenceTest.setValue('@displayDialogValue3', 'No');
                callback();
            },
            function (callback) {
                preferenceTest.closeDialog(function () {
                    callback();
                })
            },
            function (callback) {
                preferenceTest.moveToElement('@preferenceManagerBtn', 10, 10, function() {
                    client.pause(2000, function () {
                        preferenceTest.expect.element('@preferenceManagerBtn').to.not.have.attribute('aria-describedby', 'ui-tooltip');
                        callback();
                    })
                });
            }
        ], function (err, stdout) {
        });
    },

    /**
     * Test: 2-008
     * Expects:
     *  - Line, Language and Show Tooltips will reset to its initial value.
     *  Line: Bezier
     *  Language: English
     *  Show Tooltips: Yes
     */
    '2-008': function (client) {
        var preferenceTest = client.page.preferenceManagement();

        async.series([
            function (callback) {
                preferenceTest.openDialog(function() {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.clickDisplayButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.clickDisplayResetButton(function () {
                    callback();
                });
            },
            function (callback) {
                preferenceTest.expect.element('@displayDialogValue1').to.have.value.that.equals('Bezier');
                preferenceTest.expect.element('@displayDialogValue2').to.have.value.that.equals('en');
                preferenceTest.expect.element('@displayDialogValue3').to.have.value.that.equals('Yes');
                preferenceTest.expect.element('@displayDialogValue4').to.have.value.that.equals('Yes');
                preferenceTest.expect.element('@displayDialogValue5').to.have.value.that.equals('fold');
                callback();
            }
        ], function (err, stdout) {
        });
        client.end();
    }
};