var sqlite3 = require('sqlite3').verbose();
var _    = require('underscore');

var db = new sqlite3.Database('db.userfile');

var migrateDB =  function (callback) {
    db.serialize(function() {
        // Creates table if not exists
        db.run("CREATE TABLE files (" +
            "id       int(10) primary key," +
            "username TEXT not null," +
            "filename TEXT not null," +
            "category TEXT not null," +
            "filesize int(10) not null," +
            "date     datetime not null," +
            "path     TEXT" + // Adds another column 'path'
            ")"
            , function (err) {
                // If err not null, do table migration
                if (err !== null) {
                    console.log("migrating");
                    var cleanpath = function (path) {
                        path = path.replace(/\/|\\/g, '|');
                        path = _.without(path.split('|'), "");
                        path = path.join('/');
                        return path.trim();
                    };
                    var defaultDir = cleanpath(process.cwd() + '/userdata/networks');

                    // Creates a temporary table
                    db.run( "CREATE TABLE files_new (" + "\n" +
                        "id       int(10) primary key," + "\n" +
                        "username TEXT not null," + "\n" +
                        "filename TEXT not null," + "\n" +
                        "category TEXT not null," + "\n" +
                        "filesize int(10) not null," + "\n" +
                        "date     datetime not null," + "\n" +
                        "path     TEXT" + "\n" + // Adds another column 'path'
                        ");"
                    );

                    db.serialize(function () {
                        // Inserts data to temporary table from existing table
                        db.run("INSERT INTO files_new (id, username, filename, category, filesize, date) SELECT id, username, filename, category, filesize, date FROM files");

                        db.serialize(function () {
                            // Deletes the old table
                            db.run("DROP TABLE files");
                            // Renames temporary table to original name
                            db.run("ALTER TABLE files_new RENAME TO files");

                            // Updates data entries for path
                            var stmt = db.prepare("UPDATE files SET path = (?) WHERE id = (?)");
                            db.all("SELECT * FROM files WHERE path IS NULL", function (err,rows) {
                                for (var i = 0; i < rows.length; i++) {
                                    stmt.run([defaultDir + '/' + rows[i].filename, rows[i].id]);
                                }
                                stmt.finalize();
                            });
                        });
                    });

                    callback(); // Calls callback function
                }
                else {
                    console.log("creating");
                    callback(); // Calls callback function
                }
            });
    });
};

// Sync function. Calls migrateDB function.
migrateDB(function () {
    db.close();
});

