var   _      = require('underscore')
    , mysql  = require('mysql')
    , bcrypt = require('bcrypt')
    , fs     = require('fs')
    , date   = require('date-utils')
    , sqlite3= require('sqlite3'); 
var app = require('../app');
var db = new sqlite3.Database('db.userfile');

function setupUserSpace(username){
    var dir = "userdata/" + username;
    if(!fs.existsSync(dir)){
        fs.mkdirSync(dir);
    }
    if(!fs.existsSync(dir + "_package")){
        fs.mkdirSync(dir + "_package");
    }
}

exports.checklogin = function(req, res){
    conn = connect();
    console.log("in checklogin, ", req.session);
    var pass, user;
    if(req.body){
      pass = req.body.pass;
      user = req.body.user;
    }
    else if(req.query){
      pass = req.query.pass;
      user = req.query.user;
    }
    console.log("user:", user, ", pass:", pass);

    if(req.params.type === "signup"){
        console.log("signup", req.params);
        var query = "select * from accounts where username = ?";
        conn.query(query, [user], function(err, results){
            if(!results || results.length === 0){
                var parsedpass = saltyhash(pass);
                var conn2 = connect();
                conn2.query("insert into accounts" + 
                    '(username, password, created) values (?, ?, ?)',
                    [user, parsedpass, (new Date()).toFormat("YYYY-MM-DD HH24:MI:SS")]);
                conn2.query("insert into profiles" + 
                    '(username, email, numoflogins, description) values (?, "", 1, "")',
                    [user]);
                conn2.end();
                setupUserSpace(user);
                req.session.user = user;
                // res.redirect("/");
                res.send(200);
            } else {
                res.send(400, "Username already exists");
            }
            conn.destroy();
            conn2.destroy();
        });
    }
    else if(req.params.type === "login"){
        var query = "select accounts.username, password, numoflogins " +
                    "from accounts, profiles " +
                    "where profiles.username = accounts.username and accounts.username = ?";
        conn.query(query, user, function(err, results){
            console.log("login search result ", results, err);
            // console.log("saltyhashCheck ", saltyhashCheck(pass, results[0].password));
            if(results && results.length !== 0 && saltyhashCheck(pass, results[0].password)){
                req.session.user = user;
                setupUserSpace(user);
                var conn2 = connect();
                conn2.query("update profiles set numoflogins = ? where username = ?",
                  [results[0].numoflogins + 1, user], function(err, results){
                    conn2.destroy();
                  });
                console.log("session:", req.session);
                // res.redirect("/");
                res.send(200);
            }
            else{
                res.send(400, "username and password does not match");
            }
            conn.destroy();
        });
    }
    console.log("checklogin: req.session", req.session);
    // conn.end();
}


exports.logout = function(req, res){
    req.session.destroy();
    res.send(200);
}

exports.login = function(req, res){
    var css = ['stylesheetslib/smoothness/jquery-ui-1.10.2.custom.min.css',
               'stylesheets/login.css'];
    var js =  ['jslib/json2.js',
               'jslib/jquery.min.1.9.1.js',
               'jslib/jquery-ui-1.10.2.custom.min.js',
               'jslib/jquery.ui.position.js',
               'jslib/underscore.js',
               'jslib/fileBrowse.js',
               'jslib/backbone.js',
               'js/arrayObjectMixin.js',
               'js/login.js'];

    css = _.map(css, function(tmp){return app.get('rootPath') + tmp;});
    js  = _.map(js , function(tmp){return app.get('rootPath') + tmp;});
    res.render('login', {css: css, javascripts: js});
};

exports.allusers = function(req, res){
    var conn = connect();
    var query = "select accounts.username,created,numoflogins from accounts, profiles " +
                "where accounts.username = profiles.username;" 
    conn.query(query, function(err, results){
        var data = _.map(results, function(r){
          return {username: r.username,
                  created : r.created,
                  numoflogins: r.numoflogins
          };});
        res.json(data);
        conn.destroy();
    });
};

exports.admin = function(req, res){
    var css = ['stylesheetslib/smoothness/jquery-ui-1.10.2.custom.min.css',
               'stylesheets/admin.css'
              ];
    var js =  ['jslib/json2.js',
               'jslib/jquery.min.1.9.1.js',
               'jslib/jquery-ui-1.10.2.custom.min.js',
               'jslib/jquery.ui.position.js',
               'jslib/underscore.js',
               'jslib/fileBrowse.js',
               'jslib/backbone.js',
               'js/arrayObjectMixin.js',
               'js/admin.js'];
    res.render("admin", {css: css, js: js});
};

function connect(){
    var dbsetup = module.parent.exports.set("dbsetup");

    return mysql.createConnection({
        host    : dbsetup.host,
        port    : dbsetup.port,
        database: dbsetup.dbname,
        user    : dbsetup.dbuser,
        password: dbsetup.dbpassword
    }); 
}

function saltyhash(raw){
    var salt = bcrypt.genSaltSync(10);
    return bcrypt.hashSync(raw, salt);
}

function saltyhashCheck(raw, hashed){
    return bcrypt.compareSync(raw, hashed);
}


exports.deluser = function(req, res){
    var conn = connect();
    var query = "delete from accounts where username = ?";
    console.log("in deluser", req.params);
    conn.query(query, req.params.name, function(err, results){
        if(err){
          console.log("deluser", err, results);
          res.send(404);
        }
        else{
          fs.renameSync("userdata/" + req.params.name,
                        "userdata/deleted_" + req.params.name);
          res.send(200);
        }
        conn.destroy();
    });
}

exports.updateuser = function(req, res){
    var conn = connect();
    var query = "update accounts set password = ? where username = ?";
    console.log("in updateuser", req.body.newpassword);
    conn.query(query, [saltyhash(req.body.newpassword), req.params.name],
      function(err, results){
        if(err){
          console.log("in updateuser error", err, results);
          res.send(404);
        }
        else{
          console.log("in updateuser noerror", req.body.newpassword);
          res.send(200);
        }
        conn.destroy();
    });
}
